package com.simuwang.manage.api.company;

import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.pojo.dto.query.CompanyEmailHistoryPageQuery;
import com.simuwang.base.pojo.dto.query.CompanyEmailPageQuery;
import com.simuwang.base.pojo.vo.*;
import com.simuwang.logging.SystemLog;
import com.simuwang.manage.service.CompanyEmailConfigService;
import com.simuwang.manage.service.CompanyEmailSendHistoryService;
import com.simuwang.manage.service.CompanyReportFrequencyService;
import com.simuwang.manage.service.ContactInformationService;
import com.smppw.common.pojo.ResultVo;
import com.smppw.common.pojo.enums.status.ResultCode;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
/**
 * 公司邮箱配置管理
 * Author:   chenjianhua
 * Date:     2024/9/6 15:25
 * Description: ${DESCRIPTION}
 */
@SystemLog(value = "公司邮箱配置管理")
@RestController
@RequestMapping("/v1/company")
public class CompanyEmailSendHistoryController{
    private static final Logger logger = LoggerFactory.getLogger(CompanyEmailSendHistoryController.class);
    @Autowired
    private CompanyEmailSendHistoryService companyEmailSendHistoryService;

    @Autowired
    private CompanyEmailConfigService companyEmailConfigService;

    @Autowired
    private CompanyReportFrequencyService companyReportFrequencyService;

    @Autowired
    private ContactInformationService contactInformationService;
    /**
     * 公司邮箱页面展示查询
     * @param companyEmailPageQuery
     * @return
     */
    @SystemLog(value = "公司邮箱查询")
    @RequestMapping("search-company-email")
    public MybatisPage<CompanyEmailSendHistoryVO> searchCompanyEmail(CompanyEmailPageQuery companyEmailPageQuery){
        MybatisPage<CompanyEmailSendHistoryVO> result = companyEmailSendHistoryService.searchCompanyEmail(companyEmailPageQuery);
        return result;
    }

    /**
     * 根据公司ID查询邮箱发送历史
     * @param  companyEmailHistoryPageQuery
     * @return
     */
    @SystemLog(value = "公司邮箱发送历史查询")
    @RequestMapping("search-email-history")
    public MybatisPage<CompanyEmailSendHistoryVO> searchEmailHistory(CompanyEmailHistoryPageQuery companyEmailHistoryPageQuery){
        MybatisPage<CompanyEmailSendHistoryVO> result = companyEmailSendHistoryService.searchEmailHistory(companyEmailHistoryPageQuery);
        return result;
    }


    /**
     * 根据ID查询邮箱配置信息
     * @param idVO
     * @return
     */
    @SystemLog(value = "公司邮箱配置查询")
    @RequestMapping("search-email-config")
    public ResultVo<CompanyEmailConfigVO> searchEmailConfig(IdVO idVO){
        CompanyEmailConfigVO configVO = companyEmailSendHistoryService.searchEmailConfig(idVO);
        return ResultVo.ok(configVO);
    }

    /**
     * 根据公司ID批量删除邮箱配置
     * @param idListVO
     * @return
     */
    @SystemLog(value = "删除公司邮箱配置", type = SystemLog.Type.DELETE)
    @PostMapping("delete-company-email")
    public boolean deleteEmail(@RequestBody IdListVO idListVO){
        companyEmailSendHistoryService.deleteEmail(idListVO.getIdList());
        return true;
    }

    /**
     * 根据ID批量删除邮箱发送历史数据
     * @param comyanyEmailIdVO 已选行的idList
     * @return
     */
    @SystemLog(value = "删除公司邮箱发送历史", type = SystemLog.Type.DELETE)
    @PostMapping("delete-email-history")
    public boolean deleteEmailHistory(@RequestBody IdListVO comyanyEmailIdVO){
        companyEmailSendHistoryService.deleteEmailHistory(comyanyEmailIdVO.getIdList());
        return true;
    }

    /**
     * 保存邮箱配置
     * @param contactInformationVO
     * @return
     */
    @SystemLog(value = "保存公司邮箱", type = SystemLog.Type.INSERT)
    @PostMapping("save-email-config")
    public ResultVo saveContactInformation(@RequestBody List<ContactInformationVO> contactInformationVO){
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS.getCode());
        try{
            vo = contactInformationService.saveContactInformation(contactInformationVO);
        }catch (Exception e){
            logger.error(e.getMessage(),e);
            vo.setData(false);
            vo.setCode(ResultCode.SAVE_FAILED.getCode());
        }
        return vo;
    }

    /**
     * 保存公司数据报送频率
     * @param companyReportFrequencyVO
     * @return
     */
    @SystemLog(value = "保存公司数据报送频率", type = SystemLog.Type.INSERT)
    @PostMapping("/save-company-frequency")
    public ResultVo saveCompanyEmailConfig(@RequestBody CompanyReportFrequencyVO companyReportFrequencyVO){
        ResultVo vo = companyReportFrequencyService.saveCompanyReportFrequency(companyReportFrequencyVO);
        return vo;
    }


    /**
     * 修改邮箱配置
     * @param companyEmailConfigVO
     * @return
     */
    @SystemLog(value = "修改公司邮箱", type = SystemLog.Type.UPDATE)
    @PostMapping("update-email-config")
    public boolean updateCompanyEmailConfig(@RequestBody CompanyEmailConfigVO companyEmailConfigVO){
        companyEmailConfigService.updateCompanyEmailConfig(companyEmailConfigVO);
        return true;
    }

    /**
     * 根据ID删除邮箱配置
     * @param comyanyEmailIdVO --id
     * @return
     */
    @SystemLog(value = "删除公司邮箱", type = SystemLog.Type.DELETE)
    @PostMapping("delete-email-config")
    public boolean deleteCompanyEmailConfig(@RequestBody IdVO comyanyEmailIdVO){
        companyEmailConfigService.deleteCompanyEmailConfig(comyanyEmailIdVO.getId());
        return true;
    }


    /**
     * 根据companyIdList发送数据缺失邮件
     * @param idListVO  已选行的companyIdList
     * @return
     */
    @SystemLog(value = "发送缺失数据")
    @PostMapping("send-company-email")
    public boolean sendCompanyEmail(@RequestBody IdListVO idListVO){
        companyEmailConfigService.sendCompanyEmail(idListVO.getIdList());
        return true;
    }



}
